<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="88"/>
        <location filename="../main.cpp" line="120"/>
        <source>Deepin Movie</source>
        <translation>Deepin Filmi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Deepin Movie is a well-designed and full-featured video player with simple borderless design. It supports local and streaming media play with multiple video formats.</source>
        <translation>Filmi Deepin je natančno oblikovan in dopolnjen video predvajalnik s preprostim, a močnim dizajnom. Podpira predvajanje lokalne in pretočne vsebine različnih video formatov.</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="116"/>
        <source>Invalid folder</source>
        <translation>Neveljavna mapa</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="130"/>
        <source>Open Folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="121"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nimate dovoljenja za upravljanje te mape</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="5"/>
        <source>Auto add similar files to play</source>
        <translation>Samodejno dodaj podobne datoteke na seznam</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="6"/>
        <source>Clear playlist when exit</source>
        <translation>Ob izhodu izprazni seznam predvajanja</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="7"/>
        <source>Show video preview on mouseover</source>
        <translation>Ob primiku z miško pokaži predogled posnetka</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="8"/>
        <source>Open a new player for each file played</source>
        <translation>Odpri nov predvajalnik za vsako datoteko</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="9"/>
        <source>Pause when minimized</source>
        <translation>Ustavi, ko se pomanjša</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="10"/>
        <source>Remember playback position</source>
        <translation>Zapomni si položaj predvajane vsebine</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="11"/>
        <source>Path</source>
        <translation>Pot</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="12"/>
        <source>Basic</source>
        <translation>Osnove</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="13"/>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="14"/>
        <location filename="../common/settings_translation.cpp" line="19"/>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="15"/>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="16"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="17"/>
        <source>Frame/Sound</source>
        <translation>Slika/zvok</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="18"/>
        <source>Playback</source>
        <translation>Predvajanje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="20"/>
        <location filename="../common/settings_translation.cpp" line="21"/>
        <source>Subtitle</source>
        <translation>Podnapisi</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="22"/>
        <source>Font Style</source>
        <translation>Stil pisave</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="23"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzeto</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="24"/>
        <source>Open file</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="25"/>
        <source>Open next</source>
        <translation>Odpri naslednje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="26"/>
        <source>Open previous</source>
        <translation>Odpri prejšnje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="27"/>
        <source>Mini mode</source>
        <translation>Pomanjšano</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="28"/>
        <source>Mute</source>
        <translation>Utišaj</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="29"/>
        <source>Next frame</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="30"/>
        <source>Previous frame</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="31"/>
        <source>volume down</source>
        <translation>tišje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="32"/>
        <source>Volume up</source>
        <translation>Glasneje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="33"/>
        <source>Speed up</source>
        <translation>Pospeši</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="34"/>
        <source>Speed down</source>
        <translation>Počasneje</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="35"/>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="36"/>
        <source>Pause/Play</source>
        <translation>Premor/predvajaj</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="37"/>
        <source>Playlist</source>
        <translation>Seznam predvajanja</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="38"/>
        <source>Reset speed</source>
        <translation>Ponastavi hitrost</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="39"/>
        <source>Rewind</source>
        <translation>Prevrti nazaj</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="40"/>
        <source>Forward</source>
        <translation>Previj naprej</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="41"/>
        <source>Burst screenshot</source>
        <translation>Zaslonski posnetek Burst</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="42"/>
        <source>Film screenshot</source>
        <translation>Slika filma</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="43"/>
        <source>0.5s backward</source>
        <translation>0,5 s nazaj</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="44"/>
        <source>0.5s forward</source>
        <translation>0,5 s naprej</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="45"/>
        <source>Font</source>
        <translation>Pisava</translation>
    </message>
    <message>
        <location filename="../common/settings_translation.cpp" line="46"/>
        <source>Font Size</source>
        <translation>Velikost pisave</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="42"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="../widgets/url_dialog.cpp" line="46"/>
        <source>Please enter the URL:</source>
        <translation>Prosim, vnesite URL-naslov:</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../common/actions.cpp" line="82"/>
        <location filename="../common/actions.cpp" line="102"/>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="84"/>
        <location filename="../common/actions.cpp" line="269"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="85"/>
        <source>Light Theme</source>
        <translation>Svetla tema</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="108"/>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="110"/>
        <source>Always on Top</source>
        <translation>Vedno na vrhu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="284"/>
        <source>Film info</source>
        <translation>Podatki o filmu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="83"/>
        <location filename="../common/actions.cpp" line="103"/>
        <source>Open Folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="104"/>
        <source>Open URL</source>
        <translation>Odpri URL naslov</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="105"/>
        <source>Open CD/DVD</source>
        <translation>Odpri CD/DVD</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="109"/>
        <source>Mini Mode</source>
        <translation>Pomanjšano</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="115"/>
        <source>Play Mode</source>
        <translation>Način predvajanja</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="118"/>
        <source>Order Play</source>
        <translation>Vrstni red predvajanja </translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="119"/>
        <source>Shuffle Play</source>
        <translation>Mešanje predvajanja</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="120"/>
        <source>Single Play</source>
        <translation>Enojno predvajanje</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="121"/>
        <source>Single Loop</source>
        <translation>Enojna zanka</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="122"/>
        <source>List Loop</source>
        <translation>Zanka seznamov</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="129"/>
        <source>Frame</source>
        <translation>Slika</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="132"/>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="140"/>
        <source>Clockwise</source>
        <translation>V smeri urinega kazalca</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="141"/>
        <source>Counterclockwise</source>
        <translation>Proti urinemu kazalcu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="144"/>
        <source>Next frame</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="145"/>
        <source>Previous frame</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="152"/>
        <source>Sound</source>
        <translation>Zvok</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="155"/>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="158"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="159"/>
        <source>Left channel</source>
        <translation>Levi kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="160"/>
        <source>Right channel</source>
        <translation>Desni kanal</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="166"/>
        <source>Track</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="176"/>
        <source>Subtitle</source>
        <translation>Podnapisi</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="177"/>
        <source>Load</source>
        <translation>Naloži</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="178"/>
        <source>Online Search</source>
        <translation>Spletno brskanje</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="182"/>
        <source>Select</source>
        <translation>Izberi</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="186"/>
        <source>Hide</source>
        <translation>Skrij</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="190"/>
        <source>Encodings</source>
        <translation>Encodings</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="258"/>
        <source>Screenshot</source>
        <translation>Slika zaslona</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="259"/>
        <source>Film Screenshot</source>
        <translation>Slika filma</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="260"/>
        <source>Burst Shooting</source>
        <translation>Intervalno slikanje</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="267"/>
        <source>Playlist</source>
        <translation>Seznam predvajanja</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="268"/>
        <source>Film Info</source>
        <translation>Podatki o filmu</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="282"/>
        <source>Clear playlist</source>
        <translation>Počisti seznam predvajanja</translation>
    </message>
    <message>
        <location filename="../common/actions.cpp" line="283"/>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>duration: %1</source>
        <translation>čas trajanja: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
        <source>resolution: %1</source>
        <translation>ločljivost: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
        <source>size: %1</source>
        <translation>velikost: %1</translation>
    </message>
    <message>
        <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
        <source>save</source>
        <translation>shrani</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../common/mainwindow.cpp" line="785"/>
        <location filename="../common/mainwindow.cpp" line="2284"/>
        <location filename="../common/mainwindow.cpp" line="2381"/>
        <source>Deepin Movie</source>
        <translation>Deepin Filmi</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Load successfully</source>
        <translation>Uspešno naloženo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="698"/>
        <location filename="../common/mainwindow.cpp" line="1789"/>
        <source>Load failed</source>
        <translation>Nalaganje neuspešno</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1392"/>
        <source>No device found</source>
        <translation>Ne najdem naprave</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1410"/>
        <source>Parse Failed</source>
        <translation>Razčlenjevanje ni uspelo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1417"/>
        <source>Open Folder</source>
        <translation>Odpri mapo</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1432"/>
        <location filename="../common/mainwindow.cpp" line="1449"/>
        <location filename="../common/mainwindow.cpp" line="1784"/>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1434"/>
        <location filename="../common/mainwindow.cpp" line="1451"/>
        <source>All videos (%1)</source>
        <translation>Vsi posnetki (%1)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1652"/>
        <source>Muted</source>
        <translation>Utišano</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1655"/>
        <location filename="../common/mainwindow.cpp" line="1667"/>
        <location filename="../common/mainwindow.cpp" line="1677"/>
        <location filename="../common/mainwindow.cpp" line="1684"/>
        <source>Volume: %1%</source>
        <translation>Glasnost: %1%</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1749"/>
        <location filename="../common/mainwindow.cpp" line="1757"/>
        <source>Subtitle %1: %2s</source>
        <translation>Podnapisi %1: %2s</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1750"/>
        <location filename="../common/mainwindow.cpp" line="1758"/>
        <source>delayed</source>
        <translation>zamaknjeno</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1750"/>
        <location filename="../common/mainwindow.cpp" line="1758"/>
        <source>advanced</source>
        <translation>napredno</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1765"/>
        <location filename="../common/mainwindow.cpp" line="1772"/>
        <location filename="../common/mainwindow.cpp" line="1779"/>
        <source>Speed: %1x</source>
        <translation>Hitrost: %1x</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1786"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
        <translation>Podnapisi (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1848"/>
        <source>View</source>
        <translation>Prikaži</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1859"/>
        <source>Movie Screenshot</source>
        <translation>Zaslonski posnetek filma</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1860"/>
        <source>Saved to</source>
        <translation>Shranjeno v</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1874"/>
        <location filename="../common/mainwindow.cpp" line="1957"/>
        <source>The screenshot is saved</source>
        <translation>Slika je shranjena</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="1874"/>
        <source>The screenshot is failed to save</source>
        <translation>Slike ni bilo mogoče shraniti</translation>
    </message>
    <message>
        <location filename="../common/mainwindow.cpp" line="2044"/>
        <location filename="../common/mainwindow.cpp" line="2741"/>
        <source>Invalid file: %1</source>
        <translation>Neveljavna datoteka: %1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="118"/>
        <source>File Type:</source>
        <translation>Tip datoteke:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="119"/>
        <source>Resolution:</source>
        <translation>Ločljivost:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="120"/>
        <source>File Size:</source>
        <translation>Velikost datoteke:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="121"/>
        <source>Duration:</source>
        <translation>Čas trajanja:</translation>
    </message>
    <message>
        <location filename="../widgets/movieinfo_dialog.cpp" line="126"/>
        <source>File Path:</source>
        <translation>Pot datoteke:</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1029"/>
        <location filename="../backends/mpv/mpv_proxy.cpp" line="1047"/>
        <source>[internal]</source>
        <translation>[internal]</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../widgets/playlist_widget.cpp" line="192"/>
        <location filename="../widgets/playlist_widget.cpp" line="227"/>
        <location filename="../widgets/playlist_widget.cpp" line="402"/>
        <source>File does not exist</source>
        <translation>Datoteka ne obstaja</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../common/dmr_settings.cpp" line="155"/>
        <source>%1/DMovie%2.jpg</source>
        <translation>%1/DFilm%2.jpg</translation>
    </message>
    <message>
        <location filename="../common/dmr_settings.cpp" line="161"/>
        <source>%1/DMovie%2(%3).jpg</source>
        <translation>%1/DFilm%2(%3).jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="889"/>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="685"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Previous</source>
        <translation>Predhodni</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="686"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Next</source>
        <translation>Naslednji</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="687"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Subtitles</source>
        <translation>Podnapisi</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="688"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <source>Playlist</source>
        <translation>Seznam predvajanja</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="689"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="697"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="876"/>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="683"/>
        <location filename="../widgets/toolbox_proxy.cpp" line="696"/>
        <source>Play/Pause</source>
        <translation>Predvajaj/premor</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="873"/>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <location filename="../widgets/toolbox_proxy.cpp" line="886"/>
        <source>Pause</source>
        <translation>Premor</translation>
    </message>
</context>
</TS>